CalendarStyle class

The styles for the calendar. Adapt the colors and text styles for the component.

Constructors

CalendarStyle({Color? backgroundColor, Color? headerColor, TextStyle? dateTextStyle, TextStyle? hourTextStyle, TextStyle? eventTitleTextStyle, TextStyle? eventDescriptionTextStyle, Color? loadingIndicatorColor, Color? timeIndicatorColor, Color? todayIndicatorColor})

Properties

backgroundColor → Color?
final
dateTextStyle → TextStyle?
final
eventDescriptionTextStyle → TextStyle?
final
eventTitleTextStyle → TextStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
headerColor → Color?
final
hourTextStyle → TextStyle?
final
loadingIndicatorColor → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeIndicatorColor → Color?
final
todayIndicatorColor → Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited